==> aws-sdk-cpp-1.11.700-1-x86_64.pkg.tar.zst: usr/include/aws/rds/model/DeleteCustomDBEngineVersionRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/rds/RDSRequest.h>
#include <aws/rds/RDS_EXPORTS.h>

#include <utility>

namespace Aws {
namespace RDS {
namespace Model {

/**
 */
class DeleteCustomDBEngineVersionRequest : public RDSRequest {
 public:
  AWS_RDS_API DeleteCustomDBEngineVersionRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "DeleteCustomDBEngineVersion"; }

  AWS_RDS_API Aws::String SerializePayload() const override;

 protected:
  AWS_RDS_API void DumpBodyToUrl(Aws::Http::URI& uri) const override;

 public:
  ///@{
  /**
   * <p>The database engine. RDS Custom for Oracle supports the following values:</p>
   * <ul> <li> <p> <code>custom-oracle-ee</code> </p> </li> <li> <p>
   * <code>custom-oracle-ee-cdb</code> </p> </li> <li> <p>
   * <code>custom-oracle-se2</code> </p> </li> <li> <p>
   * <code>custom-oracle-se2-cdb</code> </p> </li> </ul>
   */
  inline const Aws::String& GetEngine() const { return m_engine; }
  inline bool EngineHasBeenSet() const { return m_engineHasBeenSet; }
  template <typename EngineT = Aws::String>
  void SetEngine(EngineT&& value) {
    m_engineHasBeenSet = true;
    m_engine = std::forward<EngineT>(value);
  }
  template <typename EngineT = Aws::String>
  DeleteCustomDBEngineVersionRequest& WithEngine(EngineT&& value) {
    SetEngine(std::forward<EngineT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The custom engine version (CEV) for your DB instance. This option is required
   * for RDS Custom, but optional for Amazon RDS. The combination of
   * <code>Engine</code> and <code>EngineVersion</code> is unique per customer per
   * Amazon Web Services Region.</p>
   */
  inline const Aws::String& GetEngineVersion() const { return m_engineVersion; }
  inline bool EngineVersionHasBeenSet() const { return m_engineVersionHasBeenSet; }
  template <typename EngineVersionT = Aws::String>
  void SetEngineVersion(EngineVersionT&& value) {
    m_engineVersionHasBeenSet = true;
    m_engineVersion = std::forward<EngineVersionT>(value);
  }
  template <typename EngineVersionT = Aws::String>
  DeleteCustomDBEngineVersionRequest& WithEngineVersion(EngineVersionT&& value) {
    SetEngineVersion(std::forward<EngineVersionT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_engine;
  bool m_engineHasBeenSet = false;

  Aws::String m_engineVersion;
  bool m_engineVersionHasBeenSet = false;
};

}  // namespace Model
}  // namespace RDS
}  // namespace Aws

==> aws-sdk-cpp-1.11.705-1-x86_64.pkg.tar.zst: usr/include/aws/rds/model/DeleteCustomDBEngineVersionRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/rds/RDSRequest.h>
#include <aws/rds/RDS_EXPORTS.h>

#include <utility>

namespace Aws {
namespace RDS {
namespace Model {

/**
 */
class DeleteCustomDBEngineVersionRequest : public RDSRequest {
 public:
  AWS_RDS_API DeleteCustomDBEngineVersionRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "DeleteCustomDBEngineVersion"; }

  AWS_RDS_API Aws::String SerializePayload() const override;

 protected:
  AWS_RDS_API void DumpBodyToUrl(Aws::Http::URI& uri) const override;

 public:
  ///@{
  /**
   * <p>The database engine.</p> <p>RDS Custom for Oracle supports the following
   * values:</p> <ul> <li> <p> <code>custom-oracle-ee</code> </p> </li> <li> <p>
   * <code>custom-oracle-ee-cdb</code> </p> </li> <li> <p>
   * <code>custom-oracle-se2</code> </p> </li> <li> <p>
   * <code>custom-oracle-se2-cdb</code> </p> </li> </ul> <p>RDS Custom for SQL Server
   * supports the following values:</p> <ul> <li> <p>
   * <code>custom-sqlserver-ee</code> </p> </li> <li> <p>
   * <code>custom-sqlserver-se</code> </p> </li> <li> <p>
   * <code>ccustom-sqlserver-web</code> </p> </li> <li> <p>
   * <code>custom-sqlserver-dev</code> </p> </li> </ul> <p>RDS for SQL Server
   * supports only <code>sqlserver-dev-ee</code>.</p>
   */
  inline const Aws::String& GetEngine() const { return m_engine; }
  inline bool EngineHasBeenSet() const { return m_engineHasBeenSet; }
  template <typename EngineT = Aws::String>
  void SetEngine(EngineT&& value) {
    m_engineHasBeenSet = true;
    m_engine = std::forward<EngineT>(value);
  }
  template <typename EngineT = Aws::String>
  DeleteCustomDBEngineVersionRequest& WithEngine(EngineT&& value) {
    SetEngine(std::forward<EngineT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The custom engine version (CEV) for your DB instance. This option is required
   * for RDS Custom, but optional for Amazon RDS. The combination of
   * <code>Engine</code> and <code>EngineVersion</code> is unique per customer per
   * Amazon Web Services Region.</p>
   */
  inline const Aws::String& GetEngineVersion() const { return m_engineVersion; }
  inline bool EngineVersionHasBeenSet() const { return m_engineVersionHasBeenSet; }
  template <typename EngineVersionT = Aws::String>
  void SetEngineVersion(EngineVersionT&& value) {
    m_engineVersionHasBeenSet = true;
    m_engineVersion = std::forward<EngineVersionT>(value);
  }
  template <typename EngineVersionT = Aws::String>
  DeleteCustomDBEngineVersionRequest& WithEngineVersion(EngineVersionT&& value) {
    SetEngineVersion(std::forward<EngineVersionT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_engine;
  bool m_engineHasBeenSet = false;

  Aws::String m_engineVersion;
  bool m_engineVersionHasBeenSet = false;
};

}  // namespace Model
}  // namespace RDS
}  // namespace Aws
